@@ -8,11 +8,11 @@ import logging
 import itertools
 import contextlib
 import dataclasses
+import importlib.metadata
 from collections import Counter, defaultdict
 
 import zigpy.state
 import async_timeout
-import pkg_resources
 import zigpy.zdo.types as zdo_t
 import zigpy.exceptions
 from zigpy.exceptions import NetworkNotFormed
@@ -136,10 +136,9 @@ class ZNP:
         )
 
         version = await self.request(c.SYS.Version.Req())
-        package_version = pkg_resources.get_distribution("zigpy_znp").version
 
         network_info = zigpy.state.NetworkInfo(
-            source=f"zigpy-znp@{package_version}",
+            source=f"zigpy-znp@{importlib.metadata.version('zigpy-znp')}",
             extended_pan_id=nib.extendedPANID,
             pan_id=nib.nwkPanId,
             nwk_update_id=nib.nwkUpdateId,
@@ -345,7 +344,8 @@ class ZNP:
         """
         from zigpy_znp.znp import security
 
-        await self.reset_network_info()
+        if not network_info.stack_specific.get("form_quickly", False):
+            await self.reset_network_info()
 
         # Form a network with completely random settings to get NVRAM to a known state
         for item, value in {
@@ -378,6 +378,14 @@ class ZNP:
         await self.start_network()
         await self.reset()
 
+        if network_info.stack_specific.get("form_quickly", False):
+            await self.nvram.osal_write(
+                OsalNvIds.ZIGPY_ZNP_MIGRATION_ID,
+                t.uint8_t(NVRAM_MIGRATION_ID),
+                create=True,
+            )
+            return
+
         LOGGER.debug("Writing actual network settings")
 
         # Now that we have a formed network, update its state
