@@ -16,6 +16,7 @@ import async_timeout
 import zigpy.profiles
 import zigpy.zdo.types as zdo_t
 import zigpy.application
+import zigpy.config.defaults
 from zigpy.exceptions import DeliveryError
 
 import zigpy_znp.const as const
@@ -183,7 +184,7 @@ class ControllerApplication(zigpy.application.ControllerApplication):
         if "tclk_seed" not in network_info.stack_specific["zstack"]:
             network_info.stack_specific["zstack"]["tclk_seed"] = os.urandom(16).hex()
 
-        return await self._znp.write_network_info(
+        await self._znp.write_network_info(
             network_info=network_info, node_info=node_info
         )
 
@@ -228,7 +229,10 @@ class ControllerApplication(zigpy.application.ControllerApplication):
             )
 
         # Now that we know what device we are, set the max concurrent requests
-        if self._config[conf.CONF_MAX_CONCURRENT_REQUESTS] is None:
+        if self._config[conf.CONF_MAX_CONCURRENT_REQUESTS] in (
+            None,
+            zigpy.config.defaults.CONF_MAX_CONCURRENT_REQUESTS_DEFAULT,
+        ):
             max_concurrent_requests = 16 if self._znp.nvram.align_structs else 2
         else:
             max_concurrent_requests = self._config[conf.CONF_MAX_CONCURRENT_REQUESTS]
@@ -835,6 +839,9 @@ class ControllerApplication(zigpy.application.ControllerApplication):
                 Data=data,
             )
 
+        if self._znp is None:
+            raise DeliveryError("Coordinator is disconnected, cannot send request")
+
         # Z-Stack requires special treatment when sending ZDO requests
         if dst_ep == ZDO_ENDPOINT:
             # XXX: Joins *must* be sent via a ZDO command, even if they are directly
